@@ -55,7 +55,7 @@ tracker_extract_new_artist (const char *name)
 	artist = tracker_resource_new (uri);
 
 	tracker_resource_set_uri (artist, "rdf:type", "nmm:Artist");
-	tracker_resource_set_string (artist, "nmm:artistName", name);
+	tracker_guarantee_resource_utf8_string (artist, "nmm:artistName", name);
 
 	g_free (uri);
 
@@ -128,11 +128,11 @@ tracker_extract_new_equipment (const char *make,
 	tracker_resource_set_uri (equipment, "rdf:type", "nfo:Equipment");
 
 	if (make) {
-		tracker_resource_set_string (equipment, "nfo:manufacturer", make);
+		tracker_guarantee_resource_utf8_string (equipment, "nfo:manufacturer", make);
 	}
 
 	if (model) {
-		tracker_resource_set_string (equipment, "nfo:model", model);
+		tracker_guarantee_resource_utf8_string (equipment, "nfo:model", model);
 	}
 
 	g_free (equip_uri);
@@ -190,19 +190,19 @@ tracker_extract_new_location (const char *street_address,
 		g_free (addruri);
 
 		if (street_address) {
-			tracker_resource_set_string (address, "nco:streetAddress", street_address);
+			tracker_guarantee_resource_utf8_string (address, "nco:streetAddress", street_address);
 		}
 
 		if (state) {
-			tracker_resource_set_string (address, "nco:region", state);
+			tracker_guarantee_resource_utf8_string (address, "nco:region", state);
 		}
 
 		if (city) {
-			tracker_resource_set_string (address, "nco:locality", city);
+			tracker_guarantee_resource_utf8_string (address, "nco:locality", city);
 		}
 
 		if (country) {
-			tracker_resource_set_string (address, "nco:country", country);
+			tracker_guarantee_resource_utf8_string (address, "nco:country", country);
 		}
 
 		tracker_resource_set_relation (location, "slo:postalAddress", address);
@@ -290,7 +290,7 @@ tracker_extract_new_music_album_disc (const char      *album_title,
 
 	tracker_resource_set_uri (album_disc, "rdf:type", "nmm:MusicAlbumDisc");
 	tracker_resource_set_int (album_disc, "nmm:setNumber", disc_number > 0 ? disc_number : 1);
-	tracker_resource_add_relation (album_disc, "nmm:albumDiscAlbum", album);
+	tracker_resource_set_relation (album_disc, "nmm:albumDiscAlbum", album);
 
 	g_free (tmp_album_uri);
 	g_free (tmp_disc_uri);
