@@ -494,9 +494,8 @@ main (int argc, char *argv[])
 	/* Main loop */
 	main_loop = g_main_loop_new (NULL, FALSE);
 
-	if (domain_ontology) {
-		domain_name = tracker_domain_ontology_get_domain (domain_ontology, "Tracker1");
-		g_bus_watch_name_on_connection (connection, domain_name,
+	if (domain_ontology && domain_ontology_name) {
+		g_bus_watch_name_on_connection (connection, domain_ontology_name,
 		                                G_BUS_NAME_WATCHER_FLAGS_NONE,
 		                                NULL, on_domain_vanished,
 		                                main_loop, NULL);
